<?php
  namespace Drupal\time_clock\Form;
  use Drupal\Core\Form\ConfigFormBase;
  use Drupal\Core\Form\FormStateInterface;
  use Drupal\Core\Config\ConfigFactoryInterface;
  use Drupal\Core\Cache\CacheBackendInterface;
  use Symfony\Component\DependencyInjection\ContainerInterface;

  class timeClockForm extends ConfigFormBase {

    /**
     * The cache render service.
     *
     * @var \Drupal\Core\Cache\CacheBackendInterface
     */
    protected $cacheRender;

    /**
     * Construct a timeClockForm object.
     *
     * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
     *   The factory for configuration objects.
     *
     * @param \Drupal\Core\Cache\CacheBackendInterface $cache_render
     *   A cache backend interface instance.
     *
     */
    public function __construct(ConfigFactoryInterface $config_factory, 
      CacheBackendInterface $cache_render) {
      parent::__construct($config_factory);
      $this->cacheRender = $cache_render;
    }

    /**
     * {@inheritdoc}
     */
    public static function create(ContainerInterface $container) {
      return new static(
        $container->get('config.factory'),
        $container->get('cache.config'),
      );
    }

    /**
     * {@inheritdoc}
     */
    protected function getEditableConfigNames() {
      return ['time_clock.settings'];
    }

    /**
     * {@inheritdoc}
     */
    public function getFormId() {
      return 'time_clock';
    }

    /**
     * {@inheritdoc}
     */
    public function buildForm(array $form, FormStateInterface $form_state) {
      $config = $this->config('time_clock.settings');
      $timezone = array(
        'America/Chicago' => $this->t('America/Chicago'), 
        'America/New_York' => $this->t('America/New_York'), 
        'Asia/Tokyo' => $this->t('Asia/Tokyo'), 
        'Asia/Dubai' => $this->t('Asia/Dubai'), 
        'Asia/Kolkata' => $this->t('Asia/Kolkata'), 
        'Europe/Amsterdam' => $this->t('Europe/Amsterdam'),
        'Europe/Oslo' => $this->t('Europe/Oslo'),
        'Europe/London' => $this->t('Europe/London')
      );
      $form['timezone'] = array (
        '#type' => 'select',
        '#title' => $this->t('Timezone'),
        '#options' => $timezone,
        '#default_value' => $config->get('timezone'),
        '#required' => TRUE,
      );
      $form['dateformat'] = [
        '#type' => 'select',
        '#title' => $this->t('Date Format'),
        '#default_value' => $config->get('dateformat'),
        '#options' => [
          $this->t('Default'),
          $this->t('12/31/1980'),
          $this->t('31/12/1980'),
          $this->t('1980/12/31')
        ],
      ];
      $form['dateview'] = [
        '#type' => 'checkbox',
        '#title' => $this->t('Show date'),
        '#default_value' => $config->get('dateview')
      ];
      $form['timeformat'] = [
        '#type' => 'checkbox',
        '#title' => $this->t('Show time in 24 hours'),
        '#default_value' => $config->get('timeformat')
      ];

      return parent::buildForm($form, $form_state);
    }

    /**  
     * {@inheritdoc}
     */  
    public function submitForm(array &$form, FormStateInterface $form_state) {
      parent::submitForm($form, $form_state);
      $timezone = $form_state->getValue('timezone');
      $dateformat = $form_state->getValue('dateformat');
      $timeformat = $form_state->getValue('timeformat');
      $dateview = $form_state->getValue('dateview');
      
      // Set the posted values
      $this->configFactory->getEditable('time_clock.settings')
        ->set('timezone', $timezone)
        ->set('dateformat', $dateformat)
        ->set('timeformat', $timeformat)
        ->set('dateview', $dateview)
        ->save();
    }

  }
