<?php
  /**
   * Provide a Block
   */
  namespace Drupal\time_clock\Plugin\Block;

  use Drupal\Core\Block\BlockBase;
  use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
  use Drupal\Core\Cache\Cache;
  use Drupal\Core\Config\ConfigFactoryInterface;
  use Drupal\Core\Datetime\DateFormatterInterface;
  use Symfony\Component\DependencyInjection\ContainerInterface;

  /**
   * Provides a 'Time Clock' block.
   *
   * @Block(
   *   id = "time_clock",
   *   admin_label = @Translation("Time Clock"),
   *   category = @Translation("General"),
   * )
   */
  class timeClockBlock extends BlockBase implements ContainerFactoryPluginInterface {

    /**
     * The date formatter service.
     *
     * @var \Drupal\Core\Datetime\DateFormatterInterface
     */
    protected $dateFormatter;

    /**
     * The config factory service.
     *
     * @var \Drupal\Core\Config\ConfigFactoryInterface
     */
    protected $configFactory;

    /**
     * Constructs a new WorkspaceSwitcherBlock instance.
     *
     * @param array $configuration
     *   The plugin configuration.
     *
     * @param string $plugin_id
     *   The plugin ID.
     *
     * @param mixed $plugin_definition
     *   The plugin definition.
     *
     * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
     *   The config factory.
     *
     * @param \Drupal\Core\Datetime\DateFormatterInterface $date_formatter
     *   The date formatter service.
     */
    public function __construct(array $configuration, $plugin_id, $plugin_definition, 
      ConfigFactoryInterface $config_factory, DateFormatterInterface  $date_formatter) {
      parent::__construct($configuration, $plugin_id, $plugin_definition);
      $this->configFactory = $config_factory;
      $this->dateFormatter = $date_formatter;
    }

    /**
     * {@inheritdoc}
     */
    public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
      return new static(
        $configuration,
        $plugin_id,
        $plugin_definition,
        $container->get('config.factory'),
        $container->get('date.formatter'),
      );
    }

    /**
     * {@inheritdoc}
     */
    public function build() {
      $admin_config = $this->configFactory->get('time_clock.settings');
      $timezone = $admin_config->get('timezone');
      //dd($timezone);
      $dateformat = $admin_config->get('dateformat');
      if ($dateformat == 1) {
        $date_format = 'm/d/Y';
      } elseif ($dateformat == 2) {
        $date_format = 'd/m/Y';
      } elseif ($dateformat == 3) {
        $date_format = 'Y/m/d';
      } else {
        $date_format = 'jS M, Y';
      }
      $timeformat = $admin_config->get('timeformat');
      if ($timeformat) {
        $time_format = 'H:i:s';
      } else {
        $time_format = 'g:i:s A';
      }
      $items = [];
      if (!empty($timezone)) {
        // Set the default timezone value
        date_default_timezone_set($timezone);
        $dateview = $admin_config->get('dateview');
        if ($dateview) {
          $date = $this->dateFormatter->format(time(), 'custom', $date_format);
        } else {
          $date = '';
        }
        $time = $this->dateFormatter->format(time(), 'custom', $time_format);

        $items = array(
          'timezone' => $timezone,
          'date' => $date,
          'time' => $time,
          
        );
      }
      $data['#theme'] = 'time_clock';
      $data['#attached']['library'] = array('time_clock/clock-style');
      $data['#attached']['drupalSettings']['timezone'] = $timezone;
      $data['#attached']['drupalSettings']['timeformat'] = $timeformat;
      $data['#data'] = $items;
      
      return $data;
    }

    // Disable cache for this block
    public function getCacheMaxAge() {
      return 0;
    }
    
  }
